@@ -8,6 +8,8 @@
 #include <adwaita.h>
 #include <signal.h>
 #include <stdlib.h>
+#include <glib.h>
+#include <sigc++/functors/functors.h>
 
 #include "application.h"
 #include "procdialogs.h"
@@ -131,11 +133,6 @@ cb_timeouts_changed (Gio::Settings& settings,
       load_graph_change_speed (app->disk_graph,
                                app->config.graph_update_interval);
     }
-  else if (key == GSM_SETTING_DISKS_UPDATE_INTERVAL)
-    {
-      app->config.disks_update_interval = settings.get_int (key);
-      disks_reset_timeout (app);
-    }
 }
 
 static void
@@ -305,8 +302,6 @@ GsmApplication::load_settings ()
   this->settings->signal_changed (GSM_SETTING_PROCESS_UPDATE_INTERVAL).connect (cbtc);
   config.graph_update_interval = this->settings->get_int (GSM_SETTING_GRAPH_UPDATE_INTERVAL);
   this->settings->signal_changed (GSM_SETTING_GRAPH_UPDATE_INTERVAL).connect (cbtc);
-  config.disks_update_interval = this->settings->get_int (GSM_SETTING_DISKS_UPDATE_INTERVAL);
-  this->settings->signal_changed (GSM_SETTING_DISKS_UPDATE_INTERVAL).connect (cbtc);
 
   config.graph_data_points = this->settings->get_int (GSM_SETTING_GRAPH_DATA_POINTS);
   this->settings->signal_changed (GSM_SETTING_GRAPH_DATA_POINTS).connect ([this](const Glib::ustring&key) {
@@ -353,6 +348,21 @@ GsmApplication::load_settings ()
     this->settings->signal_changed (k).connect (cbcc);
 }
 
+void GsmApplication::load_command_line_options ()
+{
+  for ( auto entry : option_group.entries() ) 
+  {
+    this->add_main_option_entry (
+      OptionType::BOOL, 
+      entry.get_long_name(),
+      entry.get_short_name(),
+      entry.get_description(),
+      entry.get_arg_description(),
+      entry.get_flags()
+    );
+  }
+}
+
 
 GsmApplication::GsmApplication()
   : Gtk::Application (APP_ID, Gio::Application::Flags::HANDLES_COMMAND_LINE),
@@ -387,13 +397,14 @@ GsmApplication::GsmApplication()
 
   disk_list (NULL),
 
-  disk_timeout (0U),
-
   selection (NULL),
 
   smooth_refresh (NULL)
 {
   Glib::set_application_name (_("System Monitor"));
+  this->set_option_context_summary (_("A simple process and system monitor."));
+  this->signal_handle_local_options().connect(sigc::mem_fun(*this, &GsmApplication::handle_local_options), false);
+  load_command_line_options ();
 }
 
 Glib::RefPtr<GsmApplication>
@@ -413,33 +424,23 @@ GsmApplication::on_activate ()
 }
 
 int
-GsmApplication::on_command_line (const Glib::RefPtr<Gio::ApplicationCommandLine>&command_line)
+GsmApplication::handle_local_options (const Glib::RefPtr<Glib::VariantDict> &content)
 {
-  int argc = 0;
-  char **argv = command_line->get_arguments (argc);
-
-  Glib::OptionContext context;
-
-  context.set_summary (_("A simple process and system monitor."));
-  context.set_ignore_unknown_options (true);
-
-  procman::OptionGroup option_group;
-
-  context.set_main_group (option_group);
-
-  try {
-      context.parse (argc, argv);
-    } catch (const Glib::Error&ex) {
-      g_error ("Arguments parse error : %s", ex.what ());
-    }
-
-  g_strfreev (argv);
+  option_group.load ( content );
 
   if (option_group.print_version)
-    {
-      g_print ("%s %s\n", _("GNOME System Monitor"), VERSION);
-      exit (EXIT_SUCCESS);
-    }
+  {
+    g_print ("%s %s\n", _("GNOME System Monitor"), VERSION);
+    return 0;
+  }
+
+  return -1;
+}
+
+int
+GsmApplication::on_command_line (const Glib::RefPtr<Gio::ApplicationCommandLine>&command_line)
+{
+  option_group.load ( command_line->get_options_dict () );
 
   const char*tab = NULL;
   if (option_group.show_processes_tab)
@@ -491,8 +492,11 @@ GsmApplication::shutdown ()
 {
   if (timeout)
     g_source_remove (timeout);
-  if (disk_timeout)
-    g_source_remove (disk_timeout);
+
+  guint disks_timeout = gsm_disks_view_get_timeout (disk_list);
+
+  if (disks_timeout)
+    g_source_remove (disks_timeout);
 
   proctable_free_table (this);
   delete smooth_refresh;
@@ -507,17 +511,23 @@ void
 GsmApplication::on_startup ()
 {
   AdwStyleManager *style_manager;
+  GtkCssProvider *css_provider;
 
   Gtk::Application::on_startup ();
 
   glibtop_init ();
 
   load_resources ();
-  load_settings ();
 
   style_manager = adw_style_manager_get_default ();
   adw_style_manager_set_color_scheme (style_manager, ADW_COLOR_SCHEME_PREFER_LIGHT);
 
+  css_provider = gtk_css_provider_new ();
+  gtk_css_provider_load_from_resource (css_provider, "/org/gnome/gnome-system-monitor/style.css");
+  gtk_style_context_add_provider_for_display (gdk_display_get_default (),
+                                              GTK_STYLE_PROVIDER (css_provider),
+                                              GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
   Gtk::Window::set_default_icon_name (APP_ID);
 
   Glib::RefPtr<Gio::SimpleAction> action;
@@ -542,6 +552,7 @@ GsmApplication::on_startup ()
 
   set_accel_for_action ("win.show-dependencies", "<Primary>d");
   set_accel_for_action ("app.quit", "<Primary>q");
+  set_accel_for_action ("window.close", "<Primary>w");
   set_accel_for_action ("win.send-signal-stop", "<Primary>s");
   set_accel_for_action ("win.send-signal-cont", "<Primary>c");
   set_accel_for_action ("win.send-signal-term", "<Primary>t");
@@ -554,8 +565,8 @@ GsmApplication::on_startup ()
   set_accel_for_action ("app.help", "F1");
   set_accel_for_action ("win.show-help-overlay", "<Control>question");
   set_accel_for_action ("app.preferences", "<Primary>comma");
-  set_accel_for_action ("win.show-page('processes')", "<Alt>1");
-  set_accel_for_action ("win.show-page('resources')", "<Alt>2");
+  set_accel_for_action ("win.show-page('resources')", "<Alt>1");
+  set_accel_for_action ("win.show-page('processes')", "<Alt>2");
   set_accel_for_action ("win.show-page('disks')", "<Alt>3");
   set_accel_for_action ("win.refresh", "<Control>r");
 
@@ -563,7 +574,7 @@ GsmApplication::on_startup ()
 
   pretty_table = new PrettyTable ();
   smooth_refresh = new SmoothRefresh (settings);
-
+  
   create_main_window (this);
 }
 
