@@ -10,10 +10,12 @@
 
 struct LoadGraph;
 
+#include "disks.h"
 #include "smooth_refresh.h"
 #include "prettytable.h"
 #include "legacy/treeview.h"
 #include "util.h"
+#include "argv.h"
 
 static const unsigned MIN_UPDATE_INTERVAL = 1 * 1000;
 static const unsigned MAX_UPDATE_INTERVAL = 100 * 1000;
@@ -21,8 +23,8 @@ static const unsigned MAX_UPDATE_INTERVAL = 100 * 1000;
 
 enum ProcmanTab
 {
-  PROCMAN_TAB_PROCESSES,
   PROCMAN_TAB_RESOURCES,
+  PROCMAN_TAB_PROCESSES,
   PROCMAN_TAB_DISKS
 };
 
@@ -34,7 +36,6 @@ struct ProcConfig
     : current_tab (),
     update_interval (0),
     graph_update_interval (0),
-    disks_update_interval (0),
     graph_data_points (0),
     mem_color (),
     swap_color (),
@@ -60,7 +61,6 @@ struct ProcConfig
   Glib::ustring current_tab;
   int update_interval;
   int graph_update_interval;
-  int disks_update_interval;
   int graph_data_points;
   GdkRGBA cpu_color[GLIBTOP_NCPU];
   GdkRGBA mem_color;
@@ -213,11 +213,13 @@ class GsmApplication: public Gtk::Application, private procman::NonCopyable
 private:
 void                                load_settings ();
 void                                load_resources ();
+void                                load_command_line_options();
 
 void                                on_preferences_activate (const Glib::VariantBase&);
 void                                on_lsof_activate (const Glib::VariantBase&);
 void                                on_help_activate (const Glib::VariantBase&);
 void                                on_quit_activate (const Glib::VariantBase&);
+int                                 handle_local_options (const Glib::RefPtr<Glib::VariantDict> &);
 protected:
 GsmApplication();
 
@@ -263,13 +265,12 @@ LoadGraph        *mem_graph;
 LoadGraph        *net_graph;
 LoadGraph        *disk_graph;
 
-GsmTreeView      *disk_list;
-
-guint disk_timeout;
+GsmDisksView     *disk_list;
 
 GtkTreeSelection *selection;
 
 SmoothRefresh    *smooth_refresh;
+procman::OptionGroup option_group;
 };
 
 #endif /* _GSM_APPLICATION_H_ */
