@@ -44,15 +44,6 @@
 #include "settings-keys.h"
 #include "legacy/gsm_color_button.h"
 
-static const char*LOAD_GRAPH_CSS = "\
-.loadgraph {\
-    background: linear-gradient(to bottom,\
-                  @window_bg_color,\
-                  @view_bg_color);\
-    color: @window_fg_color;\
-}\
-";
-
 static void
 search_text_changed (GtkEditable*,
                      gpointer data)
@@ -111,8 +102,6 @@ create_proc_view (GsmApplication *app,
                     "changed",
                     G_CALLBACK (search_text_changed),
                     app);
-
-  g_object_bind_property (app->search_bar, "search-mode-enabled", app->search_button, "active", (GBindingFlags)(G_BINDING_BIDIRECTIONAL));
 }
 
 static void
@@ -231,7 +220,6 @@ create_sys_view (GsmApplication *app,
   GtkLabel *label, *cpu_label;
   GtkGrid *table;
   GsmColorButton *color_picker;
-  GtkCssProvider *provider;
 
   LoadGraph *cpu_graph, *mem_graph, *net_graph, *disk_graph;
 
@@ -240,9 +228,6 @@ create_sys_view (GsmApplication *app,
   gchar *label_text;
   gchar *title_template;
 
-  provider = gtk_css_provider_new ();
-  gtk_css_provider_load_from_string (provider, LOAD_GRAPH_CSS);
-  gtk_style_context_add_provider_for_display (gdk_display_get_default (), GTK_STYLE_PROVIDER (provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
   // Translators: color picker title, %s is CPU, Memory, Swap, Receiving, Sending
   title_template = g_strdup (_("Pick a Color for “%s”"));
 
@@ -258,7 +243,7 @@ create_sys_view (GsmApplication *app,
                    GTK_WIDGET (load_graph_get_widget (cpu_graph)));
 
   GtkGrid*cpu_table = GTK_GRID (gtk_builder_get_object (builder, "cpu_table"));
-  gint cols = 4;
+  gint cols = 4 + app->config.num_cpus / 32;
   gint rows = (app->config.num_cpus + cols - 1) / cols;
 
   for (i = 0; i < app->config.num_cpus; i++)
@@ -455,8 +440,9 @@ on_activate_about (GSimpleAction *,
                    gpointer data)
 {
   GsmApplication *app = (GsmApplication *) data;
+  AdwDialog *about_dialog;
 
-  const gchar * const authors[] = {
+  const gchar *authors[] = {
     "Kevin Vandersloot",
     "Erik Johnsson",
     "Jorgen Scheibengruber",
@@ -471,37 +457,30 @@ on_activate_about (GSimpleAction *,
     NULL
   };
 
-  const gchar * const documenters[] = {
+  const gchar *documenters[] = {
     "Bill Day",
     "Sun Microsystems",
     NULL
   };
 
-  const gchar * const artists[] = {
+  const gchar *artists[] = {
     "Baptiste Mille-Mathias",
     NULL
   };
 
-  adw_show_about_window (
-    GTK_WINDOW (app->main_window),
-    "application-name", _("System Monitor"),
-    "comments", _("View current processes and monitor "
-                  "system state"),
-    "version", VERSION,
-    "website", "https://apps.gnome.org/SystemMonitor/",
-    "copyright", "Copyright \xc2\xa9 2001-2004 Kevin Vandersloot\n"
-    "Copyright \xc2\xa9 2005-2007 Benoît Dejean\n"
-    "Copyright \xc2\xa9 2011 Chris Kühl",
-    "application-icon", APP_ID,
-    "developer-name", _("The GNOME Project"),
-    "developers", authors,
-    "artists", artists,
-    "documenters", documenters,
-    "translator-credits", _("translator-credits"),
-    "license-type", GTK_LICENSE_GPL_2_0,
-    "support-url", "https://help.gnome.org/users/gnome-system-monitor/stable/",
-    "issue-url", "https://gitlab.gnome.org/GNOME/gnome-system-monitor/issues",
-    NULL);
+  about_dialog = adw_about_dialog_new_from_appdata ("/org/gnome/gnome-system-monitor/appdata.xml",
+                                                    VERSION);
+
+  adw_about_dialog_set_copyright (ADW_ABOUT_DIALOG (about_dialog),
+                                  "Copyright \xc2\xa9 2001-2004 Kevin Vandersloot\n"
+                                  "Copyright \xc2\xa9 2005-2007 Benoît Dejean\n"
+                                  "Copyright \xc2\xa9 2011 Chris Kühl");
+  adw_about_dialog_set_developers (ADW_ABOUT_DIALOG (about_dialog), authors);
+  adw_about_dialog_set_artists (ADW_ABOUT_DIALOG (about_dialog), artists);
+  adw_about_dialog_set_documenters (ADW_ABOUT_DIALOG (about_dialog), documenters);
+  adw_about_dialog_set_translator_credits (ADW_ABOUT_DIALOG (about_dialog), _("translator-credits"));
+
+  adw_dialog_present (about_dialog, GTK_WIDGET (app->main_window));
 }
 
 static void
@@ -524,37 +503,6 @@ on_activate_refresh (GSimpleAction *,
   proctable_update (app);
 }
 
-static void
-kill_process_with_confirmation (GsmApplication *app,
-                                int             signal)
-{
-  gboolean kill_dialog = app->settings->get_boolean (GSM_SETTING_SHOW_KILL_DIALOG);
-
-  if (kill_dialog)
-    procdialog_create_kill_dialog (app, signal);
-  else
-    kill_process (app, signal);
-}
-
-static void
-on_activate_send_signal (GSimpleAction *action,
-                         GVariant *,
-                         gpointer       data)
-{
-  GsmApplication *app = (GsmApplication *) data;
-
-  const gchar *action_name = g_action_get_name (G_ACTION (action));
-
-  if (g_strcmp0 (action_name, "send-signal-cont") == 0)
-    kill_process (app, SIGCONT);
-  else if (g_strcmp0 (action_name, "send-signal-stop") == 0)
-    kill_process_with_confirmation (app, SIGSTOP);
-  else if (g_strcmp0 (action_name, "send-signal-term") == 0)
-    kill_process_with_confirmation (app, SIGTERM);
-  else if (g_strcmp0 (action_name, "send-signal-kill") == 0)
-    kill_process_with_confirmation (app, SIGKILL);
-}
-
 static void
 on_activate_set_affinity (GSimpleAction *,
                           GVariant *,
@@ -565,6 +513,22 @@ on_activate_set_affinity (GSimpleAction *,
   create_set_affinity_dialog (app);
 }
 
+static void
+create_single_memmaps_dialog (GtkTreeModel *model,
+                              GtkTreePath*,
+                              GtkTreeIter  *iter,
+                              gpointer)
+{
+  ProcInfo *info;
+  GsmMemMapsView *memmaps_view;
+
+  gtk_tree_model_get (model, iter, COL_POINTER, &info, -1);
+
+  memmaps_view = gsm_memmaps_view_new (info);
+
+  gtk_window_present (GTK_WINDOW (memmaps_view));
+}
+
 static void
 on_activate_memory_maps (GSimpleAction *,
                          GVariant *,
@@ -572,7 +536,9 @@ on_activate_memory_maps (GSimpleAction *,
 {
   GsmApplication *app = (GsmApplication *) data;
 
-  create_memmaps_dialog (app);
+  /* TODO: do we really want to open multiple dialogs ? */
+  gtk_tree_selection_selected_foreach (app->selection, create_single_memmaps_dialog,
+                                       NULL);
 }
 
 static void
@@ -754,12 +720,12 @@ update_page_activities (GsmApplication *app)
 
   if (strcmp (current_page, "disks") == 0)
     {
-      disks_update (app);
-      disks_thaw (app);
+      disks_update (app->disk_list);
+      disks_thaw (app->disk_list);
     }
   else
     {
-      disks_freeze (app);
+      disks_freeze (app->disk_list);
     }
 }
 
@@ -804,7 +770,7 @@ cb_main_window_suspended (GtkWindow*,
         }
       else if (current_page == "disks")
         {
-          disks_freeze (app);
+          disks_freeze (app->disk_list);
         }
     }
   else
@@ -823,8 +789,8 @@ cb_main_window_suspended (GtkWindow*,
         }
       else if (current_page == "disks")
         {
-          disks_update (app);
-          disks_thaw (app);
+          disks_update (app->disk_list);
+          disks_thaw (app->disk_list);
         }
     }
 }
@@ -832,14 +798,8 @@ cb_main_window_suspended (GtkWindow*,
 void
 create_main_window (GsmApplication *app)
 {
-  GdkDisplay *display;
-  GdkMonitor *monitor;
-  GdkRectangle monitor_geometry;
-  GdkSurface *surface;
   GtkBuilder *builder = gtk_builder_new ();
-  GtkNative *native;
   GError *err = NULL;
-  int width, height;
 
   gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/interface.ui", &err);
   if (err != NULL)
@@ -862,7 +822,7 @@ create_main_window (GsmApplication *app)
   app->stack = ADW_VIEW_STACK (gtk_builder_get_object (builder, "stack"));
   create_proc_view (app, builder);
   create_sys_view (app, builder);
-  create_disk_view (app, builder);
+  app->disk_list = GSM_DISKS_VIEW (gtk_builder_get_object (builder, "disks_view"));
 
   app->app_menu_button = GTK_MENU_BUTTON (gtk_builder_get_object (builder, "app_menu_button"));
   app->generic_window_menu_model = G_MENU_MODEL (gtk_builder_get_object (builder, "generic-window-menu"));
