@@ -12,13 +12,13 @@
 #include "systemd.h"
 #include "util.h"
 
-static AdwPreferencesWindow *prefs_window = NULL;
+static AdwPreferencesDialog *prefs_dialog = NULL;
 
 static gboolean
-prefs_window_close_request (GtkWindow*,
+prefs_dialog_close_request (AdwDialog*,
                             gpointer)
 {
-  prefs_window = NULL;
+  prefs_dialog = NULL;
   return FALSE;
 }
 
@@ -46,99 +46,24 @@ range_value_changed (GtkRange *self,
   procman_debug ("set %s to %d", key->str, new_value);
 }
 
-static void
-field_toggled (const gchar *gsettings_parent,
-               gchar       *path_str,
-               gpointer     data)
-{
-  GtkTreeModel *model = static_cast<GtkTreeModel*>(data);
-  GtkTreePath *path = gtk_tree_path_new_from_string (path_str);
-  GtkTreeIter iter;
-  GtkTreeViewColumn *column;
-  gboolean toggled;
-
-  if (!path)
-    return;
-
-  gtk_tree_model_get_iter (model, &iter, path);
-  gtk_tree_model_get (model, &iter, 2, &column, -1);
-  gtk_tree_model_get (model, &iter, 0, &toggled, -1);
-
-  toggled = !toggled;
-
-  gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, toggled, -1);
-  gtk_tree_view_column_set_visible (column, toggled);
-
-  auto id = gtk_tree_view_column_get_sort_column_id (column);
-  auto key = Glib::ustring::compose ("col-%1-visible", id);
-  auto settings = GsmApplication::get ()->settings->get_child (gsettings_parent);
-  settings->set_boolean (key, toggled);
-
-  gtk_tree_path_free (path);
-}
-
-static void
-field_row_activated (GtkTreeView *tree,
-                     GtkTreePath *path,
-                     GtkTreeViewColumn*,
-                     gpointer     data)
-{
-  GtkTreeModel *model = gtk_tree_view_get_model (tree);
-  gchar *path_str = gtk_tree_path_to_string (path);
-
-  field_toggled ((gchar*)data, path_str, model);
-  g_free (path_str);
-}
-
 static void
 create_field_page (GtkBuilder  *builder,
                    GtkTreeView *tree,
                    const gchar *widgetname)
 {
-  GtkTreeView *treeview;
   GList *it, *columns;
-  GtkListStore *model;
-  GtkTreeViewColumn *column;
-  GtkCellRenderer *cell;
-  gchar *full_widgetname;
+  AdwPreferencesGroup *group;
 
-  full_widgetname = g_strdup_printf ("%s_columns", widgetname);
-  treeview = GTK_TREE_VIEW (gtk_builder_get_object (builder, full_widgetname));
-  g_free (full_widgetname);
-
-  model = gtk_list_store_new (3, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_POINTER);
-
-  gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), GTK_TREE_MODEL (model));
-  g_object_unref (G_OBJECT (model));
-
-  column = gtk_tree_view_column_new ();
-  cell = gtk_cell_renderer_toggle_new ();
-  gtk_tree_view_column_pack_start (column, cell, FALSE);
-  gtk_tree_view_column_set_attributes (column, cell,
-                                       "active", 0,
-                                       NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
-
-  column = gtk_tree_view_column_new ();
-  cell = gtk_cell_renderer_text_new ();
-  gtk_tree_view_column_pack_start (column, cell, FALSE);
-  gtk_tree_view_column_set_attributes (column, cell,
-                                       "text", 1,
-                                       NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
-
-  g_signal_connect (G_OBJECT (GTK_TREE_VIEW (treeview)), "row-activated",
-                    G_CALLBACK (field_row_activated), (gpointer)widgetname);
+  group = ADW_PREFERENCES_GROUP (gtk_builder_get_object (builder, widgetname));
 
   columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (tree));
 
   for (it = columns; it; it = it->next)
     {
       GtkTreeViewColumn *column = static_cast<GtkTreeViewColumn*>(it->data);
-      GtkTreeIter iter;
       const gchar *title;
-      gboolean visible;
       gint column_id;
+      GtkWidget *row;
 
       title = gtk_tree_view_column_get_title (column);
       if (!title)
@@ -158,15 +83,57 @@ create_field_page (GtkBuilder  *builder,
           )
         continue;
 
-      visible = gtk_tree_view_column_get_visible (column);
+      row = adw_switch_row_new ();
+      adw_preferences_row_set_title (ADW_PREFERENCES_ROW (row), title);
 
-      gtk_list_store_append (model, &iter);
-      gtk_list_store_set (model, &iter, 0, visible, 1, title, 2, column, -1);
+      auto settings = GsmApplication::get ()->settings->get_child (widgetname);
+      auto key = Glib::ustring::compose ("col-%1-visible", column_id);
+
+      g_settings_bind (settings->gobj (), key.c_str (), G_OBJECT (column), "visible", G_SETTINGS_BIND_DEFAULT);
+      g_settings_bind (settings->gobj (), key.c_str (), G_OBJECT (row), "active", G_SETTINGS_BIND_DEFAULT);
+
+      adw_preferences_group_add (group, GTK_WIDGET (row));
     }
 
   g_list_free (columns);
 }
 
+static void
+create_field_page (GtkBuilder    *builder,
+                   GtkColumnView *column_view,
+                   const gchar   *widgetname)
+{
+  GListModel *columns;
+  AdwPreferencesGroup *group;
+
+  columns = gtk_column_view_get_columns (column_view);
+  group = ADW_PREFERENCES_GROUP (gtk_builder_get_object (builder, widgetname));
+  auto settings = GsmApplication::get ()->settings->get_child (widgetname);
+
+  for (guint i = 0; i < g_list_model_get_n_items (columns); i++)
+    {
+      GtkColumnViewColumn *column = GTK_COLUMN_VIEW_COLUMN (g_list_model_get_object (columns, i));
+      const gchar *title;
+      const gchar *column_id;
+      GtkWidget *row;
+
+      title = gtk_column_view_column_get_title (column);
+      if (!title)
+        title = _("Icon");
+
+      column_id = gtk_column_view_column_get_id (column);
+      row = adw_switch_row_new ();
+      adw_preferences_row_set_title (ADW_PREFERENCES_ROW (row), title);
+
+      auto key = Glib::ustring::compose ("col-%1-visible", column_id);
+
+      g_settings_bind (settings->gobj (), key.c_str (), G_OBJECT (column), "visible", G_SETTINGS_BIND_DEFAULT);
+      g_settings_bind (settings->gobj (), key.c_str (), G_OBJECT (row), "active", G_SETTINGS_BIND_DEFAULT);
+
+      adw_preferences_group_add (group, GTK_WIDGET (row));
+    }
+}
+
 static void
 switch_preferences_page (GtkBuilder   *builder,
                          AdwViewStack *stack)
@@ -176,7 +143,7 @@ switch_preferences_page (GtkBuilder   *builder,
   AdwPreferencesPage *page = ADW_PREFERENCES_PAGE (gtk_builder_get_object (builder, stack_name));
 
   if (page != NULL)
-    adw_preferences_window_set_visible_page (prefs_window, page);
+    adw_preferences_dialog_set_visible_page (prefs_dialog, page);
 }
 
 void
@@ -190,7 +157,7 @@ create_preferences_dialog (GsmApplication *app)
   gfloat update;
   GError*err = NULL;
 
-  if (prefs_window)
+  if (prefs_dialog)
     return;
 
   builder = gtk_builder_new ();
@@ -201,7 +168,7 @@ create_preferences_dialog (GsmApplication *app)
       g_error_free (err);
     }
 
-  prefs_window = ADW_PREFERENCES_WINDOW (gtk_builder_get_object (builder, "preferences_dialog"));
+  prefs_dialog = ADW_PREFERENCES_DIALOG (gtk_builder_get_object (builder, "preferences_dialog"));
 
   spin_button = ADW_SPIN_ROW (gtk_builder_get_object (builder, "processes_interval_spinner"));
   update = (gfloat) app->config.update_interval;
@@ -292,7 +259,7 @@ create_preferences_dialog (GsmApplication *app)
                    bits_total_switch, "active",
                    G_SETTINGS_BIND_DEFAULT);
 
-  update = (gfloat) app->config.disks_update_interval;
+  update = (gfloat) g_settings_get_int (app->settings->gobj (), GSM_SETTING_DISKS_UPDATE_INTERVAL);
   spin_button = ADW_SPIN_ROW (gtk_builder_get_object (builder, "devices_interval_spinner"));
   adjustment = adw_spin_row_get_adjustment (spin_button);
   gtk_adjustment_configure (adjustment, update / 1000.0, 1.0,
@@ -305,17 +272,15 @@ create_preferences_dialog (GsmApplication *app)
                    check_switch, "active",
                    G_SETTINGS_BIND_DEFAULT);
 
-  create_field_page (builder, GTK_TREE_VIEW (app->disk_list), GSM_SETTINGS_CHILD_DISKS);
+  create_field_page (builder, gsm_disks_view_get_column_view (app->disk_list),
+                     GSM_SETTINGS_CHILD_DISKS);
 
-  gtk_window_set_transient_for (GTK_WINDOW (prefs_window), GTK_WINDOW (GsmApplication::get ()->main_window));
-  gtk_window_set_modal (GTK_WINDOW (prefs_window), TRUE);
-
-  g_signal_connect (G_OBJECT (prefs_window), "close-request",
-                    G_CALLBACK (prefs_window_close_request), NULL);
+  g_signal_connect (G_OBJECT (prefs_dialog), "closed",
+                    G_CALLBACK (prefs_dialog_close_request), NULL);
 
   switch_preferences_page (builder, app->stack);
 
-  gtk_window_present (GTK_WINDOW (prefs_window));
+  adw_dialog_present (ADW_DIALOG (prefs_dialog), GTK_WIDGET (GsmApplication::get ()->main_window));
 
   g_object_unref (G_OBJECT (builder));
 }
