@@ -28,6 +28,7 @@
 #include "application.h"
 #include "proctable.h"
 #include "procdialogs.h"
+#include "settings-keys.h"
 
 
 static void
@@ -42,7 +43,7 @@ renice_single_process (GtkTreeModel *model,
   gint error;
   int saved_errno;
   gchar *error_msg;
-  AdwMessageDialog *dialog;
+  AdwAlertDialog *dialog;
 
   gtk_tree_model_get (model, iter, COL_POINTER, &info, -1);
 
@@ -80,24 +81,17 @@ renice_single_process (GtkTreeModel *model,
       "%s"),
     info->pid, args->arg_value, g_strerror (saved_errno));
 
-  dialog = ADW_MESSAGE_DIALOG (adw_message_dialog_new (
-                                 GTK_WINDOW (GsmApplication::get ()->main_window),
-                                 NULL,
-                                 NULL));
+  dialog = ADW_ALERT_DIALOG (adw_alert_dialog_new (
+                               NULL,
+                               NULL));
 
-  adw_message_dialog_format_body (dialog, "%s", error_msg);
+  adw_alert_dialog_format_body (dialog, "%s", error_msg);
 
-  adw_message_dialog_add_response (dialog, "ok", _("_OK"));
-
-  gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
-  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+  adw_alert_dialog_add_response (dialog, "ok", _("_OK"));
 
   g_free (error_msg);
 
-  g_signal_connect (dialog, "response",
-                    G_CALLBACK (gtk_window_destroy), NULL);
-
-  gtk_window_present (GTK_WINDOW (dialog));
+  adw_dialog_present (ADW_DIALOG (dialog), GTK_WIDGET (GsmApplication::get ()->main_window));
 }
 
 
@@ -121,23 +115,14 @@ renice (GsmApplication *app,
   proctable_update (app);
 }
 
-
-
-
 static void
-kill_single_process (GtkTreeModel *model,
-                     GtkTreePath*,
-                     GtkTreeIter  *iter,
-                     gpointer      data)
+kill_process_action (ProcInfo                    *info,
+                     const struct ProcActionArgs *const args)
 {
-  const struct ProcActionArgs * const args = static_cast<ProcActionArgs*>(data);
-  char *error_msg;
-  ProcInfo *info;
   int error;
   int saved_errno;
-  AdwMessageDialog *dialog;
-
-  gtk_tree_model_get (model, iter, COL_POINTER, &info, -1);
+  char *error_msg;
+  AdwAlertDialog *dialog;
 
   if (!info)
     return;
@@ -172,30 +157,73 @@ kill_single_process (GtkTreeModel *model,
       "%s"),
     info->pid, args->arg_value, g_strerror (saved_errno));
 
-  dialog = ADW_MESSAGE_DIALOG (adw_message_dialog_new (
-                                 GTK_WINDOW (GsmApplication::get ()->main_window),
-                                 NULL,
-                                 NULL));
+  dialog = ADW_ALERT_DIALOG (adw_alert_dialog_new (
+                               NULL,
+                               NULL));
 
-  adw_message_dialog_format_body (dialog, "%s", error_msg);
+  adw_alert_dialog_format_body (dialog, "%s", error_msg);
 
-  adw_message_dialog_add_response (dialog, "ok", _("_OK"));
-
-  gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
-  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+  adw_alert_dialog_add_response (dialog, "ok", _("_OK"));
 
   g_free (error_msg);
 
-  g_signal_connect (dialog, "response",
-                    G_CALLBACK (gtk_window_destroy), NULL);
-
-  gtk_window_present (GTK_WINDOW (dialog));
+  adw_dialog_present (ADW_DIALOG (dialog), GTK_WIDGET (GsmApplication::get ()->main_window));
 }
 
+static void
+kill_single_process (GtkTreeModel *model,
+                     GtkTreePath*,
+                     GtkTreeIter  *iter,
+                     gpointer      data)
+{
+  const struct ProcActionArgs * const args = static_cast<ProcActionArgs*>(data);
+  ProcInfo *info;
+
+  gtk_tree_model_get (model, iter, COL_POINTER, &info, -1);
+
+  kill_process_action (info, args);
+}
+
+void
+on_activate_send_signal (GSimpleAction *action,
+                         GVariant      *value,
+                         gpointer       data)
+{
+  GsmApplication *app = (GsmApplication *) data;
+
+  const gchar *action_name = g_action_get_name (G_ACTION (action));
+  gint32 proc = -1;
+
+  if (value)
+    proc = g_variant_get_int32 (value);
+
+  if (g_strcmp0 (action_name, "send-signal-cont") == 0)
+    kill_process (app, SIGCONT, proc);
+  else if (g_strcmp0 (action_name, "send-signal-stop") == 0)
+    kill_process_with_confirmation (app, SIGSTOP, proc);
+  else if (g_strcmp0 (action_name, "send-signal-term") == 0)
+    kill_process_with_confirmation (app, SIGTERM, proc);
+  else if (g_strcmp0 (action_name, "send-signal-kill") == 0)
+    kill_process_with_confirmation (app, SIGKILL, proc);
+}
+
+void
+kill_process_with_confirmation (GsmApplication *app,
+                                int             signal,
+                                gint32          proc)
+{
+  gboolean kill_dialog = app->settings->get_boolean (GSM_SETTING_SHOW_KILL_DIALOG);
+
+  if (kill_dialog)
+    procdialog_create_kill_dialog (app, signal, proc);
+  else
+    kill_process (app, signal, proc);
+}
 
 void
 kill_process (GsmApplication *app,
-              int             sig)
+              int             sig,
+              gint32          proc)
 {
   struct ProcActionArgs args = { app, sig };
 
@@ -205,8 +233,17 @@ kill_process (GsmApplication *app,
   */
   proctable_freeze (app);
 
-  gtk_tree_selection_selected_foreach (app->selection, kill_single_process,
-                                       &args);
+  if (proc == -1)
+    {
+      gtk_tree_selection_selected_foreach (app->selection, kill_single_process,
+                                           &args);
+    }
+  else
+    {
+      ProcInfo *info = app->processes.find (proc);
+
+      kill_process_action (info, &args);
+    }
 
   proctable_thaw (app);
 
