@@ -119,30 +119,6 @@ procman::format_duration_for_display (unsigned centiseconds)
   return g_strdup_printf (_("%u:%02u.%02u"), minutes, seconds, centiseconds);
 }
 
-
-
-GtkLabel*
-procman_make_label_for_mmaps_or_ofiles (const char *format,
-                                        const char *process_name,
-                                        unsigned    pid)
-{
-  GtkLabel*label;
-  char *name, *title;
-
-  name = mnemonic_safe_process_name (process_name);
-  title = g_strdup_printf (format, name, pid);
-  label = GTK_LABEL (gtk_label_new_with_mnemonic (title));
-  gtk_widget_set_valign (GTK_WIDGET (label), GTK_ALIGN_CENTER);
-  gtk_widget_set_halign (GTK_WIDGET (label), GTK_ALIGN_START);
-
-  g_free (title);
-  g_free (name);
-
-  return label;
-}
-
-
-
 /**
  * procman::format_size:
  * @size:
@@ -494,7 +470,7 @@ percentage_cell_data_func (GtkTreeViewColumn *,
   size = g_value_get_double (&value);
   g_value_unset (&value);
 
-  char *str = g_strdup_printf ("%.2f", size);
+  char *str = g_strdup_printf ("%.1f %%", size);
 
   g_object_set (renderer, "text", str, NULL);
   g_free (str);
@@ -537,8 +513,7 @@ size_na_cell_data_func (GtkTreeViewColumn *,
   if (size == 0)
     {
       g_object_set (renderer,
-                    "text", _("N/A"),
-                    "style", PANGO_STYLE_ITALIC,
+                    "text", "—",
                     NULL);
     }
   else
@@ -546,7 +521,6 @@ size_na_cell_data_func (GtkTreeViewColumn *,
       char *str = format_byte_size (size, GsmApplication::get ()->config.process_memory_in_iec);
       g_object_set (renderer,
                     "text", str,
-                    "style", PANGO_STYLE_NORMAL,
                     NULL);
       g_free (str);
     }
@@ -584,55 +558,14 @@ io_rate_cell_data_func (GtkTreeViewColumn *,
 
   if (size == 0)
     g_object_set (renderer,
-                  "text", _("N/A"),
-                  "style", PANGO_STYLE_ITALIC,
+                  "text", "—",
                   NULL);
   else
     g_object_set (renderer,
                   "text", procman::format_rate (size, FALSE).c_str (),
-                  "style", PANGO_STYLE_NORMAL,
                   NULL);
 }
 
-/*
-        Cell data function to format a size value with SI units (to be used only for disk size, see bugzilla 693630)
-    */
-void
-size_si_cell_data_func (GtkTreeViewColumn *,
-                        GtkCellRenderer *renderer,
-                        GtkTreeModel    *model,
-                        GtkTreeIter     *iter,
-                        gpointer         user_data)
-{
-  const guint index = GPOINTER_TO_UINT (user_data);
-
-  guint64 size;
-  GValue value = { 0 };
-
-  gtk_tree_model_get_value (model, iter, index, &value);
-
-  switch (G_VALUE_TYPE (&value))
-    {
-      case G_TYPE_ULONG:
-        size = g_value_get_ulong (&value);
-        break;
-
-      case G_TYPE_UINT64:
-        size = g_value_get_uint64 (&value);
-        break;
-
-      default:
-        g_assert_not_reached ();
-    }
-
-  g_value_unset (&value);
-
-  char *str = g_format_size (size);
-
-  g_object_set (renderer, "text", str, NULL);
-  g_free (str);
-}
-
 void
 duration_cell_data_func (GtkTreeViewColumn *,
                          GtkCellRenderer *renderer,
@@ -811,6 +744,18 @@ tree_store_update<const char>(GtkTreeModel*model,
 }
 
 
+std::string
+format_volume (guint64 size,
+               bool    want_bits)
+{
+  char*bytes = procman::format_size (size, want_bits);
+  std::string formatted (make_string (g_strdup (bytes)));
+
+  g_free (bytes);
+  return formatted;
+}
+
+
 std::string
 format_rate (guint64 rate,
              bool    want_bits)
@@ -825,13 +770,9 @@ format_rate (guint64 rate,
 
 
 std::string
-format_network (guint64 rate)
+format_network (guint64 size)
 {
-  char*bytes = procman::format_size (rate, GsmApplication::get ()->config.network_total_in_bits);
-  std::string formatted (bytes);
-
-  g_free (bytes);
-  return formatted;
+  return format_volume (size, GsmApplication::get ()->config.network_total_in_bits);
 }
 
 
@@ -842,10 +783,18 @@ format_network_rate (guint64 rate)
 }
 }
 
-Glib::ustring
-get_monospace_system_font_name ()
+
+GtkLabel *
+init_tnum_label (gint     char_width,
+                 GtkAlign halign)
 {
-  return Gio::Settings::create ("org.gnome.desktop.interface")->get_string ("monospace-font-name");
+  GtkLabel *label = make_tnum_label ();
+
+  gtk_label_set_width_chars (label, char_width);
+  gtk_widget_set_valign (GTK_WIDGET (label), GTK_ALIGN_CENTER);
+  gtk_widget_set_halign (GTK_WIDGET (label), halign);
+
+  return label;
 }
 
 
@@ -862,7 +811,6 @@ make_tnum_label (void)
   return GTK_LABEL (label);
 }
 
-
 PangoAttrList *
 make_tnum_attr_list (void)
 {
@@ -873,3 +821,90 @@ make_tnum_attr_list (void)
 
   return attrs;
 }
+
+void
+load_state (GtkColumnView *column_view,
+            const gchar   *widgetname)
+{
+  GListModel *columns;
+  gchar **order;
+  auto settings = GsmApplication::get ()->settings->get_child (widgetname);
+
+  columns = gtk_column_view_get_columns (column_view);
+  order = g_settings_get_strv (settings->gobj (), "columns-order");
+
+  for (guint pos = 0; order[pos] != NULL; pos++)
+    {
+      for (guint column_pos = 0; column_pos < g_list_model_get_n_items (columns); column_pos++)
+        {
+          GtkColumnViewColumn *column = GTK_COLUMN_VIEW_COLUMN (g_list_model_get_object (columns, column_pos));
+          const char *column_id = gtk_column_view_column_get_id (column);
+
+          if (g_strcmp0 (column_id, order[pos]) == 0)
+            {
+              gtk_column_view_insert_column (column_view, pos, column);
+
+              if (g_strcmp0 (g_settings_get_string (settings->gobj (), "sort-col"), column_id) == 0)
+                {
+                   gtk_column_view_sort_by_column (column_view, column,
+                                                   g_settings_get_int (settings->gobj (), "sort-order")
+                                                   ? GTK_SORT_DESCENDING : GTK_SORT_ASCENDING);
+                }
+
+              auto key = Glib::ustring::compose ("col-%1-visible", column_id);
+              g_settings_bind (settings->gobj (), key.c_str (), G_OBJECT (column), "visible", G_SETTINGS_BIND_DEFAULT);
+
+              key = Glib::ustring::compose ("col-%1-width", column_id);
+              g_settings_bind (settings->gobj (), key.c_str (), G_OBJECT (column), "fixed-width", G_SETTINGS_BIND_DEFAULT);
+
+              break;
+            }
+        }
+    }
+
+  g_strfreev (order);
+}
+
+void
+save_columns_state (GtkColumnView *column_view,
+                    const gchar   *widgetname)
+{
+  GListModel *columns;
+  gchar **order;
+  GtkColumnViewColumn *column;
+  guint num_columns;
+  auto settings = GsmApplication::get ()->settings->get_child (widgetname);
+
+  columns = gtk_column_view_get_columns (column_view);
+  num_columns = g_list_model_get_n_items (columns);
+
+  order = g_new0 (gchar *, num_columns + 1);
+
+  for (guint pos = 0; pos < num_columns; pos++)
+    {
+      column = GTK_COLUMN_VIEW_COLUMN (g_list_model_get_object (columns, pos));
+      order[pos] = g_strdup (gtk_column_view_column_get_id (column));
+    }
+
+  g_settings_set_strv (settings->gobj (), "columns-order", order);
+
+  g_strfreev (order);
+}
+
+void
+save_sort_state (GtkColumnView *column_view,
+                 const gchar   *widgetname)
+{
+  GtkColumnViewColumn *column;
+  GtkSorter *sorter;
+  GtkSortType sort_type;
+  auto settings = GsmApplication::get ()->settings->get_child (widgetname);
+
+  sorter = gtk_column_view_get_sorter (column_view);
+  column = gtk_column_view_sorter_get_primary_sort_column (GTK_COLUMN_VIEW_SORTER (sorter));
+
+  g_settings_set_string (settings->gobj (), "sort-col", gtk_column_view_column_get_id (column));
+  sort_type = gtk_column_view_sorter_get_primary_sort_order (GTK_COLUMN_VIEW_SORTER (sorter));
+
+  g_settings_set_int (settings->gobj (), "sort-order", sort_type == GTK_SORT_ASCENDING ? 0 : 1);
+}
