@@ -7,11 +7,6 @@
 
 using std::string;
 
-GtkLabel*
-procman_make_label_for_mmaps_or_ofiles (const char *format,
-                                        const char *process_name,
-                                        unsigned    pid);
-
 gboolean
 load_symbols (const char *module,
               ...) G_GNUC_NULL_TERMINATED;
@@ -30,9 +25,20 @@ procman_debug_real (const char *file,
                     const char *format,
                     ...) G_GNUC_PRINTF (4, 5);
 
+void
+load_state (GtkColumnView *column_view,
+            const gchar   *widgetname);
+
+void
+save_columns_state (GtkColumnView *column_view,
+                    const gchar   *widgetname);
+
+void
+save_sort_state (GtkColumnView *column_view,
+                 const gchar   *widgetname);
+
 #define procman_debug(FMT, ...) procman_debug_real (__FILE__, __LINE__, __func__, FMT, ## __VA_ARGS__)
 
-Glib::ustring                      get_monospace_system_font_name (void);
 GtkLabel *                         init_tnum_label (gint     char_width,
                                                     GtkAlign halign);
 GtkLabel *                         make_tnum_label (void);
@@ -83,13 +89,6 @@ void size_na_cell_data_func (GtkTreeViewColumn *col,
                              GtkTreeIter       *iter,
                              gpointer           user_data);
 
-void size_si_cell_data_func (GtkTreeViewColumn *col,
-                             GtkCellRenderer   *renderer,
-                             GtkTreeModel      *model,
-                             GtkTreeIter       *iter,
-                             gpointer           user_data);
-
-
 void duration_cell_data_func (GtkTreeViewColumn *col,
                               GtkCellRenderer   *renderer,
                               GtkTreeModel      *model,
